pub fn parse_output(source: &str) -> ParseOutputExpand description
Parse the complete CommonMark, GFM, front-matter, and MDI document and return the versioned wire envelope used by language bindings.
pub fn parse_output(source: &str) -> ParseOutputParse the complete CommonMark, GFM, front-matter, and MDI document and return the versioned wire envelope used by language bindings.