pub struct ParseOutput {
pub ir_version: &'static str,
pub syntax_version: &'static str,
pub capabilities: ParserCapabilities,
pub document: Document,
pub diagnostics: Vec<Diagnostic>,
}Expand description
A binding-friendly parse envelope.
Capabilities let a binding verify the features represented in this parse result before it adapts the portable tree to a host-language API.
Fields
ir_version: &'static strsyntax_version: &'static strcapabilities: ParserCapabilitiesdocument: Documentdiagnostics: Vec<Diagnostic>Trait Implementations
Sourceimpl Clone for ParseOutput
impl Clone for ParseOutput
Sourcefn clone(&self) -> ParseOutput
fn clone(&self) -> ParseOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseOutput
impl Debug for ParseOutput
impl Eq for ParseOutput
Sourceimpl PartialEq for ParseOutput
impl PartialEq for ParseOutput
Sourceimpl Serialize for ParseOutput
impl Serialize for ParseOutput
impl StructuralPartialEq for ParseOutput